@@ -89,6 +89,7 @@ class DockerCmd(object):
     def docker_deploy_compss(self, working_dir,
                             image: str = "",
                             restart: bool = True,
+                            privileged: bool = False,
                             extra_mounts: dict = {}) -> None:
         """ Starts the main COMPSs image in Docker.
         It stops any existing one since it can not coexist with itself.
@@ -138,7 +139,7 @@ class DockerCmd(object):
             ports = {"8888/tcp": 8888,  # required for jupyter notebooks
                     "8080/tcp": 8080}  # required for monitor
             m = self.client.containers.run(image=docker_image, name=master_name,
-                                    mounts=mounts, detach=True, ports=ports)
+                                    mounts=mounts, detach=True, ports=ports, privileged=privileged)
             self._generate_resources_cfg(ips=["localhost"])
             self._generate_project_cfg(ips=["localhost"])
             # don't pass configs because they need to be  overwritten when adding
