@@ -127,14 +127,7 @@ class LocalActions(Actions):
         app_dir = os.path.expanduser('~') + f'/.COMPSsApps/{env_id}/{app_name}'
         os.makedirs(app_dir, exist_ok=True)
 
-        if self.arguments.destination_dir:
-            destination_dir = self.arguments.destination_dir
-        else:
-            destination_dir = app_dir
-
-        local_app_deploy(self.arguments.source_dir, destination_dir)
-
-        self.save_app(app_name, self.arguments.source_dir, self.arguments.destination_dir)
+        local_app_deploy(self.arguments.source_dir, app_dir, self.arguments.destination_dir)
 
 
     def app_remove(self):
@@ -143,7 +136,9 @@ class LocalActions(Actions):
             apps_name = list(filter(lambda a: a.name == app_name, self.get_apps()))
             if len(apps_name) > 0:
                 app: App = apps_name[0]
-                shutil.rmtree(app.app_dir)
+                env_id = self.env_conf['name']
+                app_dir = os.path.expanduser('~') + f'/.COMPSsApps/{env_id}/{app_name}'
+                shutil.rmtree(app_dir)
                 if app.remote_dir:
                     shutil.rmtree(app.remote_dir)
                 print(f'Application `{app_name}` removed successfully')
@@ -160,11 +155,13 @@ class LocalActions(Actions):
             exit(1)
 
         app_data = []
+        env_id = self.env_conf['name']
         for app in apps:
-            dest_dir = app.remote_dir if app.remote_dir else app.app_dir
-            app_data.append([ app.name, app.source_dir, dest_dir ])
+            app_dir = os.path.expanduser('~') + f'/.COMPSsApps/{env_id}/{app.name}'
+            dest_dir = app.remote_dir if app.remote_dir else app_dir
+            app_data.append([ app.name, dest_dir ])
 
-        utils.table_print(['Name', 'Source Dir', 'Destination Dir'], app_data)
+        utils.table_print(['Name', 'Location'], app_data)
 
     def env_remove(self, env_id=None):
         super().env_remove(eid=env_id)
@@ -289,31 +286,24 @@ class LocalActions(Actions):
         if self.apps is not None:
             return self.apps
 
-        if env_id is not None:
-            app_file_apth = env_id + '/apps.json'
-        else:
-            app_file_apth = self.env_conf['env_path'] + '/apps.json'
-            
-        if os.path.isfile(app_file_apth):
-            with open(app_file_apth, 'r') as f:
-                apps_dict: List[dict] = json.load(f)
-                self.apps = [App.fromdict(app_dict) for app_dict in apps_dict]
-                return self.apps
-        else:
+        app_dir = os.path.expanduser('~') + f'/.COMPSsApps/'
+
+        if not os.path.isdir(app_dir):
             return []
-        
-
-    def save_app(self, app_name: str, source_directory: str, destination_dir: str = None):
-        app_file_apth = self.env_conf['env_path'] + '/apps.json'
-        app_info = App(app_name, self.env_conf['name'], source_directory, destination_dir).__dict__
-
-        if os.path.isfile(app_file_apth):
-            with open(app_file_apth, 'r') as f:
-                self.apps: List[dict] = json.load(f)
-            with open(app_file_apth, 'w') as f:
-                self.apps.append(app_info)
-                f.write(json.dumps(self.apps))
+            
+        if env_id is not None:
+            app_dir += str(env_id)
         else:
-            self.apps = [app_info]
-            with open(app_file_apth, 'w') as f:
-                json.dump(self.apps, f)
+            app_dir += self.env_conf['name']
+
+        apps: List[App] = []
+        for app_dir_name in os.listdir(app_dir):
+            app_dir_path = app_dir + '/' + app_dir_name
+            if os.path.isfile(app_dir_path + '/.compss'):
+                with open(app_dir_path + '/.compss', 'r') as dest_dir_file:
+                    dest_dir = dest_dir_file.read().strip()
+                apps.append(App(app_dir_name, dest_dir))
+            else:
+                apps.append(App(app_dir_name))
+        self.apps = apps
+        return apps
\ No newline at end of file
