@@ -106,11 +106,15 @@ def local_job_status(local_job_scripts_dir, jobid):
         return 'ERROR'
     return status
 
-def local_app_deploy(local_source: str, dest_dir: str):
-    os.makedirs(dest_dir, exist_ok=True)
+def local_app_deploy(local_source: str, app_dir: str, dest_dir: str = None):
+    dst = os.path.abspath(dest_dir) if dest_dir else app_dir
+    os.makedirs(dst, exist_ok=True)
     for f in os.listdir(local_source):
         if os.path.isfile(os.path.join(local_source, f)):
-            shutil.copy(os.path.join(local_source, f), os.path.join(dest_dir, f))
+            shutil.copy(os.path.join(local_source, f), os.path.join(dst, f))
         else:
-            shutil.copytree(os.path.join(local_source, f), os.path.join(dest_dir, f))
-    print('App deployed from ' + local_source + ' to ' + dest_dir)
\ No newline at end of file
+            shutil.copytree(os.path.join(local_source, f), os.path.join(dst, f))
+    if dest_dir is not None:
+        with open(app_dir + '/.compss', 'w') as f:
+            f.write(dst)
+    print('App deployed from ' + local_source + ' to ' + dst)
