@@ -41,7 +41,7 @@ class RemoteActions(Actions):
         return self.apps
 
     def init(self):
-        """ Deploys COMPSs infrastructure on remote|cluster env
+        """ Deploys COMPSs infrastructure on remote environment
 
         :param arguments: Command line arguments
         :param debug: Debug mode
@@ -72,13 +72,13 @@ class RemoteActions(Actions):
         except:
             traceback.print_exc()
             
-            print("ERROR: Cluster({}) deployment failed".format(env_id))
+            print("ERROR: Remote({}) deployment failed".format(env_id))
             self.env_remove(env_id)
 
     def run(self):
         app_name = self.arguments.app_name
         if not app_name:
-            print(f"ERROR: Application ID argument (-app) is required for executing runcompss in cluster")
+            print(f"ERROR: Application ID argument (-app) is required for executing runcompss in remote")
             exit(1)
 
         if app_name not in self.get_apps():
@@ -112,7 +112,7 @@ class RemoteActions(Actions):
         app_name = self.arguments.app_name
         
         if not app_name:
-            print(f"ERROR: Application ID argument (-app) is required for executing runcompss in cluster")
+            print(f"ERROR: Application ID argument (-app) is required for executing runcompss in remote")
             exit(1)
 
         if app_name not in self.get_apps():
@@ -264,7 +264,7 @@ class RemoteActions(Actions):
 
         if not apps:
             print('INFO: There are no applications binded to this environment yet')
-            print('       Try deploying an application to the cluster')
+            print('       Try deploying an application first with `pycompss app deploy`')
             exit(1)
 
         utils.table_print(['Name'], [[a] for a in apps])
@@ -304,7 +304,7 @@ class RemoteActions(Actions):
     def jupyter(self):
         app_name = self.arguments.app_name
         if not app_name:
-            print(f"ERROR: Application ID argument (-app) is required for starting jupyter on cluster")
+            print(f"ERROR: Application ID argument (-app) is required for starting jupyter on remote environment")
             exit(1)
 
         if app_name not in self.get_apps():
