@@ -16,7 +16,7 @@ import pycompss_cli.core.utils as utils
 # ############# #
 
 def remote_deploy_compss(env_id: str, login_info: str, modules, envars=[]) -> None:
-    """ Deploy environment COMPSs in remote cluster.
+    """ Deploy environment COMPSs in remote.
     It stops any existing one since it can not coexist with itself.
 
     :param working_dir: Given working directory
@@ -82,7 +82,7 @@ def remote_run_app(remote_dir: str, login_info: str, env_name: str, command: str
     return utils.ssh_run_commands(login_info, commands)
 
 def remote_submit_job(login_info: str, remote_dir: str, app_args: str, modules, envars=None) -> None:
-    """ Execute the given command in the cluster COMPSs environment.
+    """ Execute the given command in the remote COMPSs environment.
 
     :param cmd: Command to execute.
     :returns: The execution stdout.
